@@ -139,8 +139,7 @@ class Storage(driver.Base):
             part_size = self.buffer_size
         
         try:
-            tmp_dir = "/tmp/"+uuid.uuid1()
-            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image', dir=tmp_dir)
+            tmp_file = tempfile.mktemp(suffix=path1, prefix=str(uuid.uuid1()), dir="/tmp")
             with open(tmp_file, 'w') as f:
                 while True:
                     buf = fp.read(part_size)
